@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -169,13 +170,13 @@ parse_opt(int key, char *arg, struct argp_state *state)
                 fmtspec = lookup_format("clid");
                 break;
         case 'D': /* Date format */
-                printutmp_date_format = optarg;
+                grad_printutmp_date_format = arg;
                 break;
         case 'e': /* empty field replacement */
-                printutmp_empty_string = optarg;
+                grad_printutmp_empty_string = arg;
                 break;
         case 'f': /* filename */
-                filename = optarg;
+                filename = arg;
                 break;
         case 'F':
                 fingerd++;
@@ -187,16 +188,16 @@ parse_opt(int key, char *arg, struct argp_state *state)
                 fmtspec = lookup_format("sid");
                 break;
         case 'I': /* Ipaddr format */
-                /*FIXME set_ip_format(optarg);*/
+                /*FIXME set_ip_format(arg);*/
                 break;
         case 'l': /* long output */
                 fmtspec = lookup_format("long");
                 break;
         case 'n':
-                resolve_hostnames = 0;
+                grad_resolve_hostnames = 0;
                 break;
         case 'o':
-                fmtspec = lookup_format(optarg);
+                fmtspec = lookup_format(arg);
                 break;
         case 's':
                 secure++;
@@ -215,7 +216,7 @@ static struct argp argp = {
         parse_opt,
         NULL,
         doc,
-        rad_common_argp_child,
+        grad_common_argp_child,
         NULL, NULL
 };
 
@@ -243,17 +244,17 @@ main(int  argc, char **argv)
 		exit(1);
 
         if (!filename)
-                filename = radutmp_path;
+                filename = grad_utmp_file;
         
         /* Read the dictionary files */
         grad_dict_init();
         /* Read the "naslist" file. */
-        path = grad_mkfilename(radius_dir, RADIUS_NASLIST);
+        path = grad_mkfilename(grad_config_dir, RADIUS_NASLIST);
 	if (grad_nas_read_file(path))
                 exit(1);
         grad_free(path);
         /* Read realms */
-        path = grad_mkfilename(radius_dir, RADIUS_REALMS);
+        path = grad_mkfilename(grad_config_dir, RADIUS_REALMS);
 	grad_read_realms(path, 0, 0, NULL);
         grad_free(path);
         
@@ -363,16 +364,16 @@ radius_who()
         /*
          *      Show the users logged in on the terminal server(s).
          */
-        if ((file = rut_setent(filename, 0)) == NULL)
+        if ((file = grad_ut_setent(filename, 0)) == NULL)
                 return ;
 
-        while (up = rut_getent(file)) {
+        while (up = grad_ut_getent(file)) {
 		if (up->type == P_ACCT_DISABLED) 
 			printf(_("System accounting is disabled\n"));
 		else if (want_rad_record(up)) 
                         grad_utent_print(form, up, 1);
         }
-        rut_endent(file);
+        grad_ut_endent(file);
 }
 
 void
